@@ -60,6 +60,7 @@
     var resourceType = registry.getResourceType(resourceTypeString);
     resourceType
       .setNames(gettext('DNS Zone'), gettext('DNS Zones'))
+      .setDefaultIndexUrl('/resources/zones/')
       .setListFunction(listZones)
       .setProperty('action', {
         label: gettext('Action'),
@@ -194,7 +195,7 @@
         // listFunctions are expected to return data in "items"
         response.data.items = response.data.zones;
 
-        util.addTimestampIds(response.data.items, 'updated_at');
+        util.addTimestampIds(response.data.items, 'id', 'updated_at');
 
         return response;
       });
